## Introduction

This module is a collection of introspection functions.

Some functions are improved versions of the functions found in the [inspect module](https://docs.python.org/3/library/inspect.html), others are completely new.

## Documentation

The documentation can be found [here](https://Aran-Fey.github.io/introspection/build/html/index.html).

## Installation

```bash
python3 -m pip install introspection
```
